@@ -34,10 +34,9 @@ class Gios:
 
         self.session = session
 
-    async def update(self):  # pylint: disable=too-many-branches
+    async def update(self):
         """Update GIOS data."""
         data = {}
-        invalid_sensors = []
 
         if not self.station_name:
             stations = await self._get_stations()
@@ -67,29 +66,8 @@ class Gios:
                 ATTR_ID: sensor[ATTR_ID],
                 ATTR_NAME: sensor["param"]["paramName"],
             }
-        try:
-            for sensor in data:
-                sensor_data = await self._get_sensor(data[sensor][ATTR_ID])
-                # The GIOS server sends a null values for sensors several minutes before
-                # adding new data from measuring station. If the newest value is null
-                # we take the earlier value.
-                if len(sensor_data["values"]) > 0 or len(data) == 1:
-                    if sensor_data["values"][0][ATTR_VALUE]:
-                        data[sensor][ATTR_VALUE] = sensor_data["values"][0][ATTR_VALUE]
-                    elif sensor_data.get("values")[1][ATTR_VALUE]:
-                        data[sensor][ATTR_VALUE] = sensor_data["values"][1][ATTR_VALUE]
-                    else:
-                        self._available = False
-                        raise InvalidSensorsData("Invalid sensor data from GIOS API")
-                else:
-                    invalid_sensors.append(sensor)
-        except (IndexError, KeyError, TypeError):
-            self._available = False
-            raise InvalidSensorsData("Invalid sensor data from GIOS API")
 
-        if invalid_sensors:
-            for sensor in invalid_sensors:
-                data.pop(sensor)
+        data = await self._get_all_sensors(data)
 
         indexes = await self._get_indexes()
         try:
@@ -120,6 +98,39 @@ class Gios:
         station = await self._async_get(url)
         return station
 
+    async def _get_all_sensors(self, sensors):
+        """Retreive all sensors data."""
+        invalid_sensors = []
+        try:
+            for sensor in sensors:
+                sensor_data = await self._get_sensor(sensors[sensor][ATTR_ID])
+                # The GIOS server sends a null values for sensors several minutes before
+                # adding new data from measuring station. If the newest value is null
+                # we take the earlier value.
+                if len(sensor_data["values"]) > 0 or len(sensors) == 1:
+                    if sensor_data["values"][0][ATTR_VALUE]:
+                        sensors[sensor][ATTR_VALUE] = sensor_data["values"][0][
+                            ATTR_VALUE
+                        ]
+                    elif sensor_data.get("values")[1][ATTR_VALUE]:
+                        sensors[sensor][ATTR_VALUE] = sensor_data["values"][1][
+                            ATTR_VALUE
+                        ]
+                    else:
+                        self._available = False
+                        raise InvalidSensorsData("Invalid sensor data from GIOS API")
+                else:
+                    invalid_sensors.append(sensor)
+        except (IndexError, KeyError, TypeError):
+            self._available = False
+            raise InvalidSensorsData("Invalid sensor data from GIOS API")
+
+        if invalid_sensors:
+            for sensor in invalid_sensors:
+                sensors.pop(sensor)
+
+        return sensors
+
     async def _get_sensor(self, sensor):
         """Retreive sensor data."""
         url = URL_SENSOR.format(sensor)
